@@ -3,7 +3,7 @@
  * Print setup
  * Colour Management setup
  *
- * Copyright (c) 2004-2006 by Alastair M. Robinson
+ * Copyright (c) 2004-2007 by Alastair M. Robinson
  * Distributed under the terms of the GNU General Public License -
  * see the file named "COPYING" for more details.
  *
@@ -12,6 +12,8 @@
 
 #include <iostream>
 
+#include <sys/stat.h>
+
 #include <gutenprint/vars.h>
 
 #include <gtk/gtk.h>
@@ -29,6 +31,7 @@
 #include "support/rangeparser.h"
 #include "support/progressbar.h"
 #include "support/tiffsave.h"
+#include "support/jpegsave.h"
 #include "profilemanager/profileselector.h"
 #include "profilemanager/intentselector.h"
 #include "util.h"
@@ -181,8 +184,8 @@ void About_Dialog(GtkWindow *parent)
 	
 	GtkWidget *label=gtk_label_new("PhotoPrint "
 	PACKAGE_VERSION
-	" - copyright (c) 2004-2006\n"
-	"by Alastair M. Robinson (blackfive@fakenhamweb.co.uk)\nDistributed under the terms\nof the GNU General Public Licence.\n"
+	" - copyright (c) 2004-2007\n"
+	"by Alastair M. Robinson (amr@blackfiveservices.co.uk)\nDistributed under the terms\nof the GNU General Public Licence.\n"
 	"See the file 'COPYING' for more details.");
 	gtk_label_set_justify(GTK_LABEL(label),GTK_JUSTIFY_CENTER);
 	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox),label,TRUE,FALSE,5);
@@ -195,6 +198,8 @@ void About_Dialog(GtkWindow *parent)
 	g_object_unref(G_OBJECT(pb));
 }
 
+// FIXME!  Horrible hack to get around a symbol clash on Win32.
+#define SearchPathA SearchPath
 
 struct PathDialogData
 {
@@ -452,6 +457,200 @@ void ExportTiff_Dialog(GtkWindow *parent,PhotoPrint_State &state)
 	gtk_widget_show(hbox);
 
 
+	// Colour management
+
+	GtkWidget *outputprof=profileselector_new(&state.profilemanager,IS_TYPE_NULL,true);
+	gtk_table_attach_defaults(GTK_TABLE(table),outputprof,1,2,3,4);
+	gtk_widget_show(outputprof);
+
+	GtkWidget *profactive=gtk_check_button_new_with_label(_("Output Profile:"));
+	g_signal_connect(G_OBJECT(profactive),"toggled",G_CALLBACK(profenable_changed),outputprof);
+	gtk_table_attach_defaults(GTK_TABLE(table),profactive,0,1,3,4);
+	gtk_widget_show(profactive);
+
+#ifdef WIN32
+	char *dirname=substitute_homedir("$HOME\\My Documents\\My Pictures");
+#else
+	char *dirname=substitute_homedir("$HOME");
+#endif
+	gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(filechooser),dirname);
+	gtk_file_chooser_set_current_name(GTK_FILE_CHOOSER(filechooser),"exported.tif");
+	free(dirname);
+
+	gtk_entry_set_text(GTK_ENTRY(pagesentry),"1-");
+
+	const char *fn=state.profilemanager.FindString("ExportProfile");
+	if((!fn) || (strlen(fn)==0))
+		fn=state.profilemanager.FindString("DefaultRGBProfile");
+	if(fn && strlen(fn))
+		profileselector_set_filename(PROFILESELECTOR(outputprof),fn);
+	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(profactive),state.profilemanager.FindInt("ExportProfileActive"));
+	profenable_changed(profactive,outputprof);
+
+	gtk_widget_show(dialog);
+	
+	bool done=false;
+	while(!done)
+	{
+		gint result=gtk_dialog_run(GTK_DIALOG(dialog));
+		switch(result)
+		{
+			case GTK_RESPONSE_CANCEL:
+				done=true;
+				break;
+			case GTK_RESPONSE_OK:
+				try
+				{
+					const char *profile=profileselector_get_filename(PROFILESELECTOR(outputprof));
+					bool profileactive=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(profactive));
+					const char *pagerange=gtk_entry_get_text(GTK_ENTRY(pagesentry));
+					char *outputfilename=gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(filechooser));
+					int res=int(gtk_spin_button_get_value(GTK_SPIN_BUTTON(resspin)));
+		
+					if(outputfilename)
+					{
+						struct stat statbuf;
+						if(stat(outputfilename,&statbuf)==0)
+						{
+							GtkWidget *confirm = gtk_message_dialog_new (GTK_WINDOW(parent),GtkDialogFlags(0),
+							GTK_MESSAGE_WARNING,GTK_BUTTONS_OK_CANCEL,
+							"File exists - OK to overwrite?");
+							gint response=gtk_dialog_run (GTK_DIALOG (confirm));
+							cerr << "Response: " << response << endl;
+							if(response!=GTK_RESPONSE_OK)
+							{
+								g_free(outputfilename);
+								outputfilename=NULL;
+							}
+							gtk_widget_destroy (confirm);
+						}
+					}
+					else
+						ErrorMessage_Dialog(_("Please provide a filename."),GTK_WIDGET(parent));
+
+					if(outputfilename)
+					{				
+						state.profilemanager.SetInt("ExportProfileActive",profileactive);
+						if(profileactive)
+							state.profilemanager.SetString("ExportProfile",profile);
+		
+						cerr << "Page range: " << pagerange << endl;
+						cerr << "Resolution: " << res << endl;
+						cerr << "Using profile?: " << profileactive << endl;
+						if(profileactive)
+						cerr << "  " << profile << endl;
+		
+						RangeParser rp(pagerange,state.layout->GetPages());
+						int p;
+						CMTransformFactory *factory=state.profilemanager.GetTransformFactory();
+						while((p=rp.Next()))
+						{
+							cerr << "Exporting page " << p << " of " <<  state.layout->GetPages() << endl;
+							cerr << "To filename... ";
+							char *ftmp;
+							if(state.layout->GetPages()>1)
+								ftmp=SerialiseFilename(outputfilename,p,state.layout->GetPages());
+							else
+								ftmp=strdup(outputfilename);
+							cerr << ftmp << endl;
+
+							ImageSource *is=state.layout->GetImageSource(p-1,CM_COLOURDEVICE_EXPORT,factory,res);
+							if(is)
+							{
+								ProgressBar p(_("Exporting..."),true,GTK_WIDGET(parent));
+
+								if(profileactive)
+								{
+									CMSProfile *prof=state.profilemanager.GetProfile(CM_COLOURDEVICE_EXPORT);
+									cerr << "Got profile " << prof->GetFilename() << endl;
+									is->SetEmbeddedProfile(prof);
+									cerr << "Set profile - saving..." << endl;
+								}
+
+								TIFFSaver ts(ftmp,is);
+								ts.SetProgress(&p);
+								ts.Save();
+							}
+							
+							free(ftmp);
+						}
+						delete factory;
+						g_free(outputfilename);
+						outputfilename=NULL;
+						done=true;
+					}
+				}
+				catch (const char *error)
+				{
+					ErrorMessage_Dialog(error,GTK_WIDGET(parent));
+				}
+				break;
+		}
+	}
+	gtk_widget_destroy(dialog);
+}
+
+
+void ExportJPEG_Dialog(GtkWindow *parent,PhotoPrint_State &state)
+{
+	GtkWidget *dialog;
+	GtkWidget *hbox;
+ 	dialog=gtk_dialog_new_with_buttons(_("Export JPEG..."),
+		parent,GtkDialogFlags(0),
+		GTK_STOCK_CANCEL,GTK_RESPONSE_CANCEL,
+		GTK_STOCK_OK,GTK_RESPONSE_OK,
+		NULL);
+//	gtk_window_set_default_size(GTK_WINDOW(dialog),250,350);
+
+	hbox=gtk_hbox_new(FALSE,5);
+	GtkWidget *filechooser = gtk_file_chooser_widget_new (GTK_FILE_CHOOSER_ACTION_SAVE);
+	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox),hbox,TRUE,TRUE,5);
+	gtk_box_pack_start(GTK_BOX(hbox),filechooser,TRUE,TRUE,5);
+	gtk_widget_show(filechooser);
+	gtk_widget_show(hbox);
+
+	GtkWidget *table=gtk_table_new(2,3,FALSE);
+	gtk_container_set_border_width(GTK_CONTAINER(table),5);
+	gtk_table_set_col_spacings(GTK_TABLE(table),0);
+	gtk_table_set_row_spacings(GTK_TABLE(table),5);
+	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox),table,FALSE,FALSE,5);
+	gtk_widget_show(table);
+
+	// Filename
+
+	GtkWidget *label;
+
+	// Pages
+
+	hbox=gtk_hbox_new(FALSE,0);
+
+	label=gtk_label_new(_("Page range:"));
+	gtk_table_attach_defaults(GTK_TABLE(table),label,0,1,1,2);
+	gtk_widget_show(label);
+
+	GtkWidget *pagesentry=gtk_entry_new();
+	gtk_box_pack_start(GTK_BOX(hbox),GTK_WIDGET(pagesentry),TRUE,TRUE,0);
+	gtk_widget_show(pagesentry);
+
+	label=gtk_label_new(_("Resolution (dpi):"));
+	gtk_box_pack_start(GTK_BOX(hbox),GTK_WIDGET(label),TRUE,TRUE,20);
+	gtk_widget_show(label);
+
+	GtkWidget *resspin=gtk_spin_button_new_with_range(72,2880,1);
+	gtk_box_pack_start(GTK_BOX(hbox),GTK_WIDGET(resspin),TRUE,TRUE,0);
+	gtk_widget_show(resspin);
+
+	gtk_table_attach_defaults(GTK_TABLE(table),hbox,1,2,1,2);
+	gtk_widget_show(hbox);
+
+	// Resolution
+
+	hbox=gtk_hbox_new(FALSE,5);
+
+	gtk_table_attach_defaults(GTK_TABLE(table),hbox,1,2,2,3);
+	gtk_widget_show(hbox);
+
+
 	// Colour management
 
 	GtkWidget *outputprof=profileselector_new(&state.profilemanager,IS_TYPE_NULL,true);
@@ -541,7 +740,7 @@ void ExportTiff_Dialog(GtkWindow *parent,PhotoPrint_State &state)
 									cerr << "Set profile - saving..." << endl;
 								}
 
-								TIFFSaver ts(ftmp,is);
+								JPEGSaver ts(ftmp,is);
 								ts.SetProgress(&p);
 								ts.Save();
 							}
