@@ -116,7 +116,8 @@ void GPrinterSettings::Dump()
 
 
 GPrinterSettings::GPrinterSettings(PrintOutput &output,ConfigFile *inf,const char *section)
-	: ConfigSectionHandler(inf,section), PageExtent(), stpvars(NULL), output(output), initialised(false)
+	: ConfigSectionHandler(inf,section), PageExtent(), stpvars(NULL), output(output),
+	initialised(false), ppdsizes_workaround_done(false)
 {
 #if 0
 	cerr << "In GPrinterSetting constructor - about to call stp_init()" << endl;
@@ -195,6 +196,8 @@ void GPrinterSettings::ParseString(const char *string)
 						switch(param.p_type)
 						{
 							case STP_PARAMETER_TYPE_STRING_LIST:
+								if(strcmp("PageSize",token)==0)
+									cerr << "Setting PageSize to: " << value << endl;
 								stp_set_string_parameter(stpvars,token,value);
 								break;
 		
@@ -361,13 +364,17 @@ void GPrinterSettings::SaveSection(FILE *file)
 bool GPrinterSettings::SetDriver(const char *driver)
 {
 	bool result=true;
+	cerr << "Checking stpvars" << endl;
 	if(stpvars)
 	{
 		const char *olddriver=stp_get_driver(stpvars);
+		cerr << "Checking olddriver" << endl;
 		if(!olddriver)
 			olddriver="None";
+		cerr << "Checking driver" << endl;
 		if(!driver)
 			driver=DEFAULT_PRINTER_DRIVER;
+		cerr << "Comparing drivers" << endl;
 		if(strcmp(driver,olddriver))
 		{
 			cerr << "SetDriver(): Setting driver to " << driver << endl;
@@ -380,6 +387,7 @@ bool GPrinterSettings::SetDriver(const char *driver)
 			output.SetString("Driver",driver);
 
 			const stp_printer_t *printer=stp_get_printer(stpvars);
+			cerr << "Checking printer" << endl;
 			if(printer)
 			{
 				cerr << "Setting defaults" << endl;
@@ -390,6 +398,7 @@ bool GPrinterSettings::SetDriver(const char *driver)
 				cerr << "Unable to get printer - reverting to default driver" << endl;
 				output.SetString("Driver",DEFAULT_PRINTER_DRIVER);
 				stp_set_driver(stpvars,DEFAULT_PRINTER_DRIVER);
+				cerr << "Checking printer again" << endl;
 				if((printer=stp_get_printer(stpvars)))
 					stp_set_printer_defaults(stpvars,printer);
 				else
@@ -403,16 +412,25 @@ bool GPrinterSettings::SetDriver(const char *driver)
 
 		stp_parameter_t desc;
 		stp_describe_parameter(stpvars,"PPDFile",&desc);
+		cerr << "PPDFile parameter active? " << (desc.is_active ? "Yes" : "No") << endl;
+//		FIXME!!!
+		cerr << "Checking desc.is_active" << endl;
 		if(desc.is_active)
+//		if(0)
 		{
+			// FIXME - why is PPDFile parameter active for escp2-r300 driver?
 			cerr << "Getting default PPD..." << endl;
 			char *defppd=output.GetPPD();
+			cerr << "Checking defppd" << endl;
 			if(defppd)
 			{
 				cerr << "Setting PPDFile to " << defppd << endl;
 				stp_set_file_parameter(stpvars,"PPDFile",defppd);
 				free(defppd);
+				
+				// FIXME - does this break anything?
 
+				cerr << "Checking ppdsizes_workaround_done" << endl;
 				if(!ppdsizes_workaround_done)
 				{
 					stp_parameter_t desc2;
