@@ -49,7 +49,7 @@ static void isjpeg_error_exit (j_common_ptr cinfo)
 
 
 ImageSource_JPEG::ImageSource_JPEG(const char *filename)
-	: started(false)
+	: ImageSource(), started(false)
 {
 	cinfo=new jpeg_decompress_struct;
 	err=new ImageSource_JPEG_ErrManager;
@@ -137,8 +137,11 @@ ISDataType *ImageSource_JPEG::GetRow(int row)
 		return(rowbuffer);
 		
 	if(row<currentrow)
+	{
+		cerr << "JPEG error - can't support random access.  Row " << row << " requested after row " << currentrow << endl;
 		throw "Random access not supported for JPEG files";
-
+	}
+	
 	rowptr[0]=(JSAMPROW)tmprow;
 	for(;currentrow<row;++currentrow)
 	{
