@@ -307,12 +307,12 @@ ImageSource_Rotate::ImageSource_Rotate(ImageSource *source,int rotation,int span
 			case 0:
 			case 180:
 				cerr << "Rotate: source doesn't support random access - caching entire image" << endl;
-				this->spanrows=source->height;
+				this->spanrows=source->height+1;
 				break;
 			case 90:
 			case 270:
 				cerr << "Rotate: source doesn't support random access - caching entire image" << endl;
-				this->spanrows=source->width;
+				this->spanrows=source->width+1;
 				break;
 		}
 	}
