@@ -4,7 +4,8 @@
 typedef unsigned short ISDataType;
 #define IS_SAMPLEMAX 65535
 #define EIGHTTOIS(x) (((x) << 8) | (x))
-#define ISTOEIGHT(x) ((((x) * 65281 + 8388608) >> 24) & 0xff)
+#define ISTOEIGHT(x) (((x) >> 8) & 0xff )
+//#define ISTOEIGHT(x) ((((x) * 65281 + 8388608) >> 24) & 0xff)
 
 /* Note: 0 is Black for RGB images, but White for Greyscale and CMYK images */
 
@@ -22,6 +23,7 @@ enum IS_TYPE {
 };
 
 #define IS_TYPE_ALPHA 8
+#define IS_MAX_SAMPLESPERPIXEL 5
 #define STRIP_ALPHA(x) ((x)&~IS_TYPE_ALPHA)
 #define HAS_ALPHA(x) ((x)&IS_TYPE_ALPHA)
 
