@@ -43,9 +43,9 @@ ConfigTemplate LayoutDB::Template[]=
 
 
 Layout_ImageInfo::Layout_ImageInfo(Layout &layout, const char *filename, int page, bool allowcropping, PP_ROTATION rotation)
-	: page(page), allowcropping(allowcropping), crop_hpan(CENTRE), crop_vpan(CENTRE),
+	: PPEffectHeader(), page(page), allowcropping(allowcropping), crop_hpan(CENTRE), crop_vpan(CENTRE),
 	rotation(rotation), layout(layout), maskfilename(NULL), thumbnail(NULL), mask(NULL), transformed(NULL), selected(false),
-	customprofile(NULL), customintent(INTENT_DEFAULT)
+	customprofile(NULL), customintent(LCMSWRAPPER_INTENT_DEFAULT)
 {
 	bool relative=true;
 
@@ -65,9 +65,9 @@ Layout_ImageInfo::Layout_ImageInfo(Layout &layout, const char *filename, int pag
 
 
 Layout_ImageInfo::Layout_ImageInfo(Layout &layout, Layout_ImageInfo *ii, int page, bool allowcropping, PP_ROTATION rotation)
-	: page(page), allowcropping(allowcropping), crop_hpan(CENTRE), crop_vpan(CENTRE),
+	: PPEffectHeader(), page(page), allowcropping(allowcropping), crop_hpan(CENTRE), crop_vpan(CENTRE),
 	rotation(rotation), layout(layout), maskfilename(NULL), thumbnail(NULL), mask(NULL), transformed(NULL), selected(false),
-	customprofile(NULL), customintent(INTENT_DEFAULT)
+	customprofile(NULL), customintent(LCMSWRAPPER_INTENT_DEFAULT)
 {
 	cerr << "Stealing existing image!" << endl;
 
@@ -124,8 +124,6 @@ void Layout_ImageInfo::DrawThumbnail(GtkWidget *widget,int xpos,int ypos,int wid
 
 	RectFit *fit=r.Fit(target,allowcropping,rotation,crop_hpan,crop_vpan);
 
-	cerr << "Scaling thumbnail" << endl;
-
 	GdkPixbuf *tmp;
 	switch(fit->rotation)
 	{
@@ -170,8 +168,6 @@ void Layout_ImageInfo::DrawThumbnail(GtkWidget *widget,int xpos,int ypos,int wid
 		dh=gdk_pixbuf_get_height(transformed);
 	}
 
-	cerr << "Done - drawing..." << endl;
-	
 	if(mask)
 		maskpixbuf(transformed,fit->xoffset,fit->yoffset,dw,dh,mask);
 
@@ -181,8 +177,6 @@ void Layout_ImageInfo::DrawThumbnail(GtkWidget *widget,int xpos,int ypos,int wid
 		dw,dh,
 		GDK_RGB_DITHER_NONE,0,0);
 
-	cerr << "Done" << endl;
-
 	delete fit;
 }
 
@@ -201,10 +195,11 @@ void Layout_ImageInfo::SetMask(const char *filename)
 	}
 	if(filename)
 		maskfilename=strdup(filename);
+	FlushThumbnail();
 }
 
 
-GdkPixbuf *Layout_ImageInfo::GetThumbnail()
+GdkPixbuf *Layout_ImageInfo::GetThumbnailNoEffects()
 {
 	GError *err=NULL;
 
@@ -252,8 +247,8 @@ GdkPixbuf *Layout_ImageInfo::GetThumbnail()
 		}
 	}
 
-	if(thumbnail)
-		return(thumbnail);
+//	if(thumbnail)
+//		return(thumbnail);
 
 	cerr << "Thumbnail not cached - loading..." << endl;
 
@@ -292,8 +287,9 @@ GdkPixbuf *Layout_ImageInfo::GetThumbnail()
 	cerr << "Checking for Display Profile..." << endl;
 	CMSProfile *targetprof;
 	CMColourDevice target=CM_COLOURDEVICE_NONE;
-	if((targetprof=layout.state.profilemanager.GetProfile(CM_COLOURDEVICE_DISPLAY)))
-		target=CM_COLOURDEVICE_DISPLAY;
+	if((targetprof=layout.state.profilemanager.GetProfile(CM_COLOURDEVICE_PRINTERPROOF)))
+//		target=CM_COLOURDEVICE_DISPLAY;
+		target=CM_COLOURDEVICE_PRINTERPROOF;
 	else if((targetprof=layout.state.profilemanager.GetProfile(CM_COLOURDEVICE_DEFAULTRGB)))
 		target=CM_COLOURDEVICE_DEFAULTRGB;
 	if(targetprof)
@@ -318,9 +314,9 @@ GdkPixbuf *Layout_ImageInfo::GetThumbnail()
 			if(emb)
 			{
 				cerr << "Creating embedded->monitor transform..." << endl;
-				if(emb->GetColourSpace()==IS_TYPE_CMYK)
+				if(emb->GetColourSpace()!=IS_TYPE_RGB)
 				{
-//					Need to replace the RGB thumbnail with a CMYK version!
+//					Need to replace the RGB thumbnail with a CMYK or Greyscale version!
 					cerr << "Creating new thumbnail - CMYK->monitor" << endl;
 					int w,h;
 					w=(src->width*256)/src->height;
@@ -368,6 +364,25 @@ GdkPixbuf *Layout_ImageInfo::GetThumbnail()
 }
 
 
+GdkPixbuf *Layout_ImageInfo::GetThumbnail()
+{
+	if(thumbnail)
+		return(thumbnail);
+
+	GdkPixbuf *tn=GetThumbnailNoEffects();
+	if(tn)
+	{
+		ImageSource *src2=new ImageSource_GdkPixbuf(thumbnail);
+		src2=ApplyEffects(src2,PPEFFECT_PRESCALE);
+		GdkPixbuf *tn2=pixbuf_from_imagesource(src2);
+		delete src2;
+		g_object_unref(G_OBJECT(tn));
+		thumbnail=tn2;
+	}
+	return(thumbnail);
+}
+
+
 LayoutRectangle *Layout_ImageInfo::GetBounds()
 {
 	// Dummy function - override in subclasses!
@@ -384,6 +399,8 @@ ImageSource *Layout_ImageInfo::GetImageSource(CMColourDevice target,CMTransformF
 		cerr << "Loading image " << endl;
 		ImageSource *is=ISLoadImage(filename);
 
+		is=ApplyEffects(is,PPEFFECT_PRESCALE);
+
 		IS_TYPE colourspace=layout.GetColourSpace(target);
 
 		if(STRIP_ALPHA(is->type)==IS_TYPE_GREY)
@@ -495,22 +512,22 @@ const char *Layout_ImageInfo::GetAssignedProfile()
 }
 
 
-void Layout_ImageInfo::SetRenderingIntent(int intent)
+void Layout_ImageInfo::SetRenderingIntent(LCMSWrapper_Intent intent)
 {
 	FlushThumbnail();
 	customintent=intent;
 }
 
 
-int Layout_ImageInfo::GetRenderingIntent()
+LCMSWrapper_Intent Layout_ImageInfo::GetRenderingIntent()
 {
 	return(customintent);
 }
 
 
 Layout::Layout(PhotoPrint_State &state,Layout *oldlayout)
-	: xoffset(0), yoffset(0), pages(1), currentpage(0), backgroundfilename(NULL), background(NULL),
-	backgroundtransformed(NULL), state(state), imagelist(NULL), iterator(NULL), factory(NULL)
+	: PageExtent(), xoffset(0), yoffset(0), pages(1), currentpage(0), backgroundfilename(NULL), background(NULL),
+	backgroundtransformed(NULL), state(state), imagelist(NULL), iterator(NULL), factory(NULL), gc(NULL)
 {
 	factory=state.profilemanager.GetTransformFactory();
 }
@@ -518,6 +535,8 @@ Layout::Layout(PhotoPrint_State &state,Layout *oldlayout)
 
 Layout::~Layout()
 {
+	if(gc)
+		g_object_unref(G_OBJECT(gc));
 	if(factory)
 		delete factory;
 	if(backgroundtransformed)
@@ -700,8 +719,74 @@ void (*Layout::SetUnitFunc())(GtkWidget *wid,enum Units unit)
 }
 
 
+void Layout::DrawPreviewBG(GtkWidget *widget,int xpos,int ypos,int width,int height)
+{
+	if(!gc)
+	{
+		bgcol.pixel=0;
+		bgcol.red=65535;
+		bgcol.green=65535;
+		bgcol.blue=65535;
+
+		// Use printer and monitor profiles to calculate "paper white".
+		// If there's no display profile, then we can use the Default RGB profile instead...
+		cerr << "Checking for Display Profile..." << endl;
+		CMSProfile *targetprof;
+		CMColourDevice target=CM_COLOURDEVICE_NONE;
+		if((targetprof=state.profilemanager.GetProfile(CM_COLOURDEVICE_PRINTERPROOF)))
+			target=CM_COLOURDEVICE_PRINTERPROOF;
+		else if((targetprof=state.profilemanager.GetProfile(CM_COLOURDEVICE_DEFAULTRGB)))
+			target=CM_COLOURDEVICE_DEFAULTRGB;
+		if(targetprof)
+			delete targetprof;
+
+
+		if(target!=CM_COLOURDEVICE_NONE)
+		{
+			CMSTransform *transform=NULL;
+			cerr << "Creating default->monitor transform..." << endl;
+			transform = factory->GetTransform(target,IS_TYPE_RGB,LCMSWRAPPER_INTENT_DEFAULT);
+			if(transform)
+			{
+				cerr << "Applying transform..." << endl;
+
+				ISDataType rgbtriple[3];
+				rgbtriple[0]=bgcol.red;
+				rgbtriple[1]=bgcol.green;
+				rgbtriple[2]=bgcol.blue;
+				transform->Transform(rgbtriple,rgbtriple,1);
+				bgcol.red=rgbtriple[0];
+				bgcol.green=rgbtriple[1];
+				bgcol.blue=rgbtriple[2];
+			}
+		}
+
+		gc=gdk_gc_new(widget->window);
+		gdk_gc_set_rgb_fg_color(gc,&bgcol);
+	}
+	gdk_draw_rectangle (widget->window,
+		gc,TRUE,
+		xpos,ypos,
+		width,height);
+
+	GetImageableArea();
+	LayoutRectangle sr(leftmargin,topmargin,
+		imageablewidth,imageableheight);
+
+	double scale=width;
+	scale/=pagewidth;
+	sr.Scale(scale);
+
+	gdk_draw_rectangle (widget->window,
+		widget->style->mid_gc[widget->state],FALSE,
+		xpos+sr.x,ypos+sr.y,sr.w,sr.h);
+}
+
+
 void Layout::DrawPreview(GtkWidget *widget,int xpos,int ypos,int width,int height)
 {
+	DrawPreviewBG(widget,xpos,ypos,width,height);
+
 	Layout_ImageInfo *ii=FirstImage();
 
 	while(ii)
@@ -867,6 +952,13 @@ void Layout::FlushThumbnails()
 	delete factory;
 	factory=new CMTransformFactory(state.profilemanager);
 
+	// If the profile settings have changed, we'll flush the paper white
+	// gc too, so it's regenerate with the new settings.
+
+	if(gc)
+		g_object_unref(G_OBJECT(gc));
+	gc=NULL;
+
 	Layout_ImageInfo *ii=FirstImage();
 	while(ii)
 	{
