@@ -24,6 +24,7 @@
 
 #include "pp_mainwindow.h"
 #include "support/progressbar.h"
+#include "support/progresstext.h"
 #include "dialogs.h"
 #include "support/generaldialogs.h"
 #include "splashscreen/splashscreen.h"
@@ -161,7 +162,7 @@ int main(int argc,char **argv)
 						cerr << "Adding file: " << argv[i] << endl;
 						state.layout->AddImage(argv[i]);
 					}
-					Progress p;
+					ProgressText p;
 					state.layout->Print(&p);
 				}
 			}
