@@ -286,7 +286,7 @@ pp_layout_nup_pageview_expose( GtkWidget      *widget,
 
 	if (event->count > 0)
 		return FALSE;
-		
+
 	pageview->height=widget->allocation.height;
 	pageview->width=(pageview->layout->pagewidth*pageview->height)/pageview->layout->pageheight;
 	if(pageview->width>widget->allocation.width)
@@ -297,24 +297,10 @@ pp_layout_nup_pageview_expose( GtkWidget      *widget,
 	pageview->top=(widget->allocation.height-pageview->height)/2;
 	pageview->left=(widget->allocation.width-pageview->width)/2;
 
-	gdk_draw_rectangle (widget->window,
-		widget->style->light_gc[widget->state],TRUE,
-		pageview->left,pageview->top,
-		pageview->width,pageview->height);
-
+	pageview->layout->GetImageableArea();
 	pageview->scale=pageview->width;
 	pageview->scale/=pageview->layout->pagewidth;
 
-	pageview->layout->GetImageableArea();
-	LayoutRectangle sr(pageview->layout->leftmargin,pageview->layout->topmargin,
-		pageview->layout->imageablewidth,pageview->layout->imageableheight);
-
-	sr.Scale(pageview->scale);
-
-	gdk_draw_rectangle (widget->window,
-		widget->style->mid_gc[widget->state],FALSE,
-		pageview->left+sr.x,pageview->top+sr.y,sr.w,sr.h);
-
 	pageview->layout->DrawPreview(widget,pageview->left,pageview->top,pageview->width,pageview->height);
 
 	for(int row=0;row<pageview->layout->GetRows();++row)
