@@ -112,7 +112,9 @@ static void setcustomsizewidgets(pp_PageExtent *lo)
 {
 	GPrinter *p=&lo->state->printer;
 	int nw=0,mw=0,nh=0,mh=0;
+	cerr << "Getting size limits..." << endl;
 	p->GetSizeLimits(nw,mw,nh,mh);
+	cerr << "Comparing min and max width:" << endl;
 	if(nw==mw)
 	{
 		cerr << "No width adjustment possible..." << endl;
@@ -127,6 +129,7 @@ static void setcustomsizewidgets(pp_PageExtent *lo)
 		dimension_set_pt(DIMENSION(lo->customwidth),p->pagewidth);
 	}
 
+	cerr << "Comparing min and max height:" << endl;
 	if(nh==mh)
 	{
 		cerr << "No height adjustment possible..." << endl;
@@ -215,7 +218,7 @@ pp_pageextent_new (PageExtent *pe,PhotoPrint_State *state,GtkSizeGroup *sizegrou
 	gtk_widget_show(ob->pagesize);
 
 	// Hack around Gutenprint locale problems
-	cerr << "After reading page sizes: " << setlocale(LC_ALL,"") << endl;
+//	cerr << "After reading page sizes: " << setlocale(LC_ALL,"") << endl;
 	setlocale(LC_ALL,"");
 
 	// Custom page size
