@@ -497,21 +497,21 @@ CMSProofingTransform::CMSProofingTransform(CMSProfile *in,CMSProfile *out,CMSPro
 			break;
 	}
 
-	if(in->GetFilename())
-		cerr << "In: " << in->GetFilename() << endl;
-	cerr << "In: " << in->GetDescription() << endl;
+//	if(in->GetFilename())
+//		cerr << "In: " << in->GetFilename() << endl;
+//	cerr << "In: " << in->GetDescription() << endl;
 	if(out)
 	{
-		if(out->GetFilename())
-			cerr << "Out: " << out->GetFilename() << endl;
-		cerr << "Out: " << out->GetDescription() << endl;
+//		if(out->GetFilename())
+//			cerr << "Out: " << out->GetFilename() << endl;
+//		cerr << "Out: " << out->GetDescription() << endl;
 	}
-	if(proof->GetFilename())
-		cerr << "Proof: " << proof->GetFilename() << endl;
-	cerr << "Proof: " << proof->GetDescription() << endl;
+//	if(proof->GetFilename())
+//		cerr << "Proof: " << proof->GetFilename() << endl;
+//	cerr << "Proof: " << proof->GetDescription() << endl;
 
-	cerr << "Viewing intent: " << viewintent << endl;
-	cerr << "Rendering intent: " << proofintent << endl;
+//	cerr << "Viewing intent: " << viewintent << endl;
+//	cerr << "Rendering intent: " << proofintent << endl;
 
 	transform = cmsCreateProofingTransform(in->prof,
 		it,
@@ -561,15 +561,15 @@ CMSProofingTransform::CMSProofingTransform(CMSProfile *devicelink,CMSProfile *pr
 			break;
 	}
 
-	if(devicelink->GetFilename())
-		cerr << "DeviceLink: " << devicelink->GetFilename() << endl;
-	cerr << "DeviceLink: " << devicelink->GetDescription() << endl;
-	if(proof->GetFilename())
-		cerr << "Proof: " << proof->GetFilename() << endl;
-	cerr << "Proof: " << proof->GetDescription() << endl;
+//	if(devicelink->GetFilename())
+//		cerr << "DeviceLink: " << devicelink->GetFilename() << endl;
+//	cerr << "DeviceLink: " << devicelink->GetDescription() << endl;
+//	if(proof->GetFilename())
+//		cerr << "Proof: " << proof->GetFilename() << endl;
+//	cerr << "Proof: " << proof->GetDescription() << endl;
 
-	cerr << "Viewing intent: " << viewintent << endl;
-	cerr << "Rendering intent: " << proofintent << endl;
+//	cerr << "Viewing intent: " << viewintent << endl;
+//	cerr << "Rendering intent: " << proofintent << endl;
 
 	transform = cmsCreateProofingTransform(devicelink->prof,
 		it,
