@@ -91,12 +91,10 @@ CMSProfile *ProfileManager::GetProfile(enum CMColourDevice target)
 	switch(target)
 	{
 		case CM_COLOURDEVICE_DISPLAY:
-			cerr << "COLOURDEVICE_DISPLAY" << endl;
 			if(FindInt("MonitorProfileActive"))
 				profilename=FindString("MonitorProfile");
 			break;
 		case CM_COLOURDEVICE_PRINTERPROOF:
-			cerr << "COLOURDEVICE_PRINTERPROOF" << endl;
 			if(FindInt("MonitorProfileActive"))
 				profilename=FindString("MonitorProfile");
 			break;
@@ -182,8 +180,6 @@ CMTransformFactoryNode::CMTransformFactoryNode(CMTransformFactory *header,CMSTra
 
 CMTransformFactoryNode::~CMTransformFactoryNode()
 {
-	cerr << "Removing FactoryNode" << endl;
-
 	if(next)
 		next->prev=prev;
 	if(prev)
@@ -255,7 +251,6 @@ CMSTransform *CMTransformFactory::GetTransform(enum CMColourDevice target,CMSPro
 
 	if(target==CM_COLOURDEVICE_PRINTERPROOF)
 	{
-		cerr << "PrinterProof mode:" << endl;
 		CMSProfile *proofprofile=NULL;
 		switch(manager.FindInt("ProofMode"))
 		{
