@@ -349,6 +349,10 @@ static char *getppd(struct pqinfo *pq)
 #ifdef HAVE_LIBCUPS
 	fprintf(stderr,"Current queue: %s\n",pq->priv->currentqueue);
 	const char *ppdname=cupsGetPPD(pq->priv->currentqueue);
+	if(ppdname)
+		fprintf(stderr,"CUPS returned: %s\n",ppdname);
+	else
+		fprintf(stderr,"No PPD returned for %s\n",pq->priv->currentqueue);
 	if(ppdname)
 		result=strdup(ppdname);
 #endif
