@@ -154,9 +154,11 @@ char *File_Save_Dialog(const char *title,const char *oldfilename,GtkWidget *pare
 	{
 		newfile = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
 
+		cerr << "Checking if file " << newfile << " already exists?" << endl;
 		struct stat statbuf;
 		if(stat(newfile,&statbuf)==0)
 		{
+			cerr << "Yes - asking for confirmation before overwriting..." << endl;
 			GtkWidget *confirm = gtk_message_dialog_new (GTK_WINDOW(parent),GtkDialogFlags(0),
 			GTK_MESSAGE_WARNING,GTK_BUTTONS_OK_CANCEL,
 			"File exists - OK to overwrite?");
