@@ -1,6 +1,5 @@
 /*
  * progress.h - base class for progress displays.
- * By default, provides "twirling baton" display on stderr.
  *
  * Copyright (c) 2004 by Alastair M. Robinson
  * Distributed under the terms of the GNU General Public License -
@@ -18,34 +17,27 @@ using namespace std;
 class Progress
 {
 	public:
-	Progress() : counter(0), counter2(0)
+	Progress() : current(0), max(1)
 	{
 	}
 	virtual ~Progress()
 	{
 	}
+	virtual bool DoProgress()
+	{
+		++current;
+		return(DoProgress(current,max));
+	}
 	virtual bool DoProgress(int i, int maxi)
 	{
-		char *baton="/-\\|";
-		if((counter==0) || (i==maxi))
-		{
-			if(i>maxi)
-				i=maxi;
-			cerr << baton[counter2] << " " << ((i+1)*100)/maxi << "%\r";
-			if(i==maxi)
-				cerr << endl;
-			cerr.flush();
-			++counter2;
-			counter2&=3;
-		}
-		++counter;
-		int mod=maxi/500;
-		if(!mod)
-			mod=1;
-		counter%=mod;
+		current=i;
+		max=maxi;
 		return(true);
 	}
+	virtual void SetMessage(const char *msg)=0;
 	private:
+	int current;
+	int max;
 	int counter;
 	int counter2;
 	int limit;
